mdslogger
=========
A configurable logger.

Install
=======
pip install mds-mdslogger

Changes
=======

*0.5.3 - 10.06.2020*

- fix: usage of 'syslog' and 'ntevent' logger

*0.5.1 - 13.12.2018*

- fix: import

*0.5.0 - 13.12.2018*

- public version
